@@ -12,7 +12,8 @@
 #' If variances are specified as unequal then uses Welch's test where
 #' homogeneity of variance is not required.
 #'
-#' @usage L_2S_ttest(data, group, veq=0, null=0, d=0.5, alt.2=NULL, L.int=2, verb=TRUE)
+#' @usage L_2S_ttest(data, group, veq=0, null=0, d=0.5, alt.2=NULL,
+#' L.int=2, toler=0.0001, logplot=FALSE, supplot=-10, verb=TRUE)
 #' @param data a (non-empty) numeric vector of data values.
 #' @param group an integer vector the same length as data, coding for 2 groups.
 #' @param veq whether variances are equal: 1 = Yes, 0 = No, default = 0.
@@ -20,9 +21,11 @@
 #' @param d Cohen's effect size, default = 0.5.
 #' @param alt.2 value for an alternative hypothesis, in units used for data, default = NULL.
 #' @param L.int likelihood interval given as support values, e.g. 2 or 3, default = 2.
+#' @param toler the desired accuracy using optimise, default = 0.0001.
+#' @param logplot plot vertical axis as log likelihood, default = FALSE
+#' @param supplot set minimum likelihood display value in plot, default = -10
 #' @param verb show output, default = TRUE.
 #'
-#'
 #' @return
 #' $obs.diff - the observed difference in means.
 #'
@@ -70,7 +73,8 @@
 #' @examples # using a variation on Gosset's original additional hours of sleep data, p 59
 #' mysample <- c(0.7, -1.6, -0.2, -1.2, -0.1, 3.4, 3.7, 0.8, 0.0, 2.0)
 #' treat <- rep(1:0,each=5)
-#' L_2S_ttest(mysample, treat, veq=0, null=0, d=0.5, alt.2=2, L.int=2)
+#' L_2S_ttest(mysample, treat, veq=0, null=0, d=0.5, alt.2=2, L.int=2,
+#' toler=0.0001, logplot=FALSE, supplot=-10, verb=TRUE)
 #'
 #' @references Cahusac, P.M.B. (2020) Evidence-Based Statistics, Wiley, ISBN : 978-1119549802
 #'
@@ -84,7 +88,7 @@
 #' Journal of the American Statistical Association, 95, 760.
 
 
-L_2S_ttest <- function(data, group, veq=0, null=0, d=0.5, alt.2=NULL, L.int=2, verb=TRUE) {
+L_2S_ttest <- function(data, group, veq=0, null=0, d=0.5, alt.2=NULL, L.int=2, toler=0.0001, logplot=FALSE, supplot=-10, verb=TRUE) {
   if (is.null(d)) d = 0
   dat <- data.frame(data, group)
   ad <- dat[complete.cases(dat), ] # remove missing, NA or NaN, case-wise
@@ -130,19 +134,44 @@ L_2S_ttest <- function(data, group, veq=0, null=0, d=0.5, alt.2=NULL, L.int=2, v
 
   # Plot the likelihood function
   x=0
-  curve((1 + ((m.obs-x)/sed)^2/df)^-(N/2),
-        xlim = c(m.obs-5*sed,m.obs+5*sed), ylab = "Likelihood",
+
+  # to determine x axis space for plot
+
+  f <- function(x, m.obs, sed, df, N, goal) {
+    (-N/2*log(1 + ((m.obs-x)/sed)^2/df)-goal)^2
+  }
+
+  goalx <- supplot   # with e^-10 we get x values for when curve is down to 0.00004539
+  suppressWarnings(xmin1x <- optimize(f, c(m.obs-100*sed, m.obs), tol = toler, m.obs, sed, df, N, goalx))
+  suppressWarnings(xmin2x <- optimize(f, c(m.obs, m.obs+100*sed), tol = toler, m.obs, sed, df, N, goalx))
+  xmin <- xmin1x$minimum
+  xmax <- xmin2x$minimum
+
+  if(isFALSE(logplot)) {
+    curve((1 + ((m.obs-x)/sed)^2/df)^-(N/2),
+        xlim = c(xmin,xmax), ylab = "Likelihood",
         xlab = "Mean difference")
   lines(c(m.obs,m.obs),c(0,1),lty=2) # add mean as dashed line
   lines(c(null, null), c(0,(1 + ((m.obs-null)/sed)^2/df)^-(N/2)),lty=1, col = "black") # for null
   lines(c(alt.1,alt.1),c(0,(1 + ((m.obs-alt.1)/sed)^2/df)^-(N/2)),lty=1, col = "blue") # d
   if (!is.null(alt.2)) lines(c(alt.2,alt.2),c(0,(1 + ((m.obs-alt.2)/sed)^2/df)^-(N/2)),lty=1, col = "green") # alt.2 value
-
   # Add Likelihood interval
   lolim <- m.obs - sed*sqrt((exp(L.int*2/N)-1)*df)
   hilim <- m.obs + sed*sqrt((exp(L.int*2/N)-1)*df)
   segments(lolim, exp(-L.int), hilim, exp(-L.int), lwd = 0.2, col = "red")
-
+  } else {
+  curve(-N/2*log(1 + ((m.obs-x)/sed)^2/df),
+        xlim = c(xmin,xmax), ylim=c(supplot,0), ylab = "Log Likelihood",
+        xlab = "Mean difference")
+  lines(c(m.obs,m.obs),c(supplot,0),lty=2) # add mean as dashed line
+  lines(c(null, null), c(supplot,-N/2*log(1 + ((m.obs-null)/sed)^2/df)),lty=1, col = "black") # for null
+  lines(c(alt.1,alt.1),c(supplot,-N/2*log(1 + ((m.obs-alt.1)/sed)^2/df)),lty=1, col = "blue") # d
+  if (!is.null(alt.2)) lines(c(alt.2,alt.2),c(supplot,-N/2*log(1 + ((m.obs-alt.2)/sed)^2/df)),lty=1, col = "green") # alt.2 value
+  # Add Likelihood interval
+  lolim <- m.obs - sed*sqrt((exp(L.int*2/N)-1)*df)
+  hilim <- m.obs + sed*sqrt((exp(L.int*2/N)-1)*df)
+  segments(lolim, -L.int, hilim, -L.int, lwd = 0.2, col = "red")
+  }
   if(verb) cat("\nMaximum support for the observed mean ", m.obs, " (dashed line) against the null ",
       null, " (black line) = ", round(S_m,3), sep= "", "\n Support for d of ", d,
       " (", round(alt.1,3), ", blue line) versus null = ", round(S_10,3),
@@ -151,7 +180,7 @@ L_2S_ttest <- function(data, group, veq=0, null=0, d=0.5, alt.2=NULL, L.int=2, v
       "\n\n S-", L.int, " likelihood interval (red line) is from ", c(round(lolim,5),
                                                                       " to ", round(hilim,5)),
       "\n\nt(", round(df,1), ") = ", round(tval,3), ", p = ",
-      pval, ", d = ", round(obs_es,3), "\n ")
+      format.pval(pval,4), ", d = ", round(obs_es,3), "\n ")
 
 
   invisible(list(obs.diff = m.obs, df = df, var.eq = veq, alt.H1 = alt.1, alt.H2 = alt.2, S_max = S_m,
